EepromMapping eeprom_map_sailfish_7_7[] = {
{ "ACCELERATION_ACTIVE", "Acceleration active", "", 0x16e, et_boolean, 0, 0, 1,
  "Check or set to 1 to use acceleration.  Uncheck or set to 0 for no acceleration.  Note that you must turn acceleration on to print safely at speeds over 50mm/s." },
{ "MAX_ACCELERATION_EXTRUDER_MOVE", "Max acceleration extruder move", "mm/s²", 0x186, et_ushort, 0, 0, 0,
  "" },
{ "MAX_SPEED_CHANGE_X", "Max speed change x", "mm/s", 0x17c, et_ushort, 0, 0, 0,
  "" },
{ "MAX_SPEED_CHANGE_Y", "Max speed change y", "mm/s", 0x17e, et_ushort, 0, 0, 0,
  "" },
{ "MAX_SPEED_CHANGE_Z", "Max speed change z", "mm/s", 0x180, et_ushort, 0, 0, 0,
  "" },
{ "MAX_SPEED_CHANGE_A", "Max speed change a", "mm/s", 0x182, et_ushort, 0, 0, 0,
  "" },
{ "MAX_SPEED_CHANGE_B", "Max speed change b", "mm/s", 0x184, et_ushort, 0, 0, 0,
  "" },
{ "MAX_ACCELERATION_AXIS_X", "Max acceleration axis x", "mm/s²", 0x172, et_ushort, 0, 0, 0,
  "" },
{ "MAX_ACCELERATION_AXIS_Y", "Max acceleration axis y", "mm/s²", 0x174, et_ushort, 0, 0, 0,
  "" },
{ "MAX_ACCELERATION_AXIS_Z", "Max acceleration axis z", "mm/s²", 0x176, et_ushort, 0, 0, 0,
  "" },
{ "MAX_ACCELERATION_AXIS_A", "Max acceleration axis a", "mm/s²", 0x178, et_ushort, 0, 0, 0,
  "" },
{ "MAX_ACCELERATION_AXIS_B", "Max acceleration axis b", "mm/s²", 0x17a, et_ushort, 0, 0, 0,
  "" },
{ "MAX_ACCELERATION_NORMAL_MOVE", "Max acceleration normal move", "mm/s²", 0x170, et_ushort, 0, 0, 0,
  "" },
{ "EXTRUDER_DEPRIME_ON_TRAVEL", "Extruder deprime on travel", "", 0x20b, et_boolean, 0, 0, 1,
  "When set, the firmware will deprime the extruder on detected travel moves as well as on pauses, planned or otherwise.  When not set, the firmware will only deprime the extruder on pauses, planned or otherwise.  Unplanned pauses occur when the acceleration planner falls behind and the printer waits briefly for another segment to print." },
{ "ALEVEL_MAX_ZPROBE_HITS", "Alevel max zprobe hits", "", 0xf64, et_byte, 0, 0, 200,
  "Trigger a pause if the auto-leveling probe registers too many hits during a print. Set to the value 0 to allow an unlimited number of hits without pausing; otherwise, set to a value in the range 1 to 200." },
{ "T0_COOLING_SETPOINT_C", "T0 cooling setpoint c", "C", 0x11b, et_byte, 0, 0, 300,
  "" },
{ "T0_COOLING_ENABLE", "T0 cooling enable", "", 0x11a, et_boolean, 0, 0, 1,
  "" },
{ "T0_EXTRUDER_P_TERM", "T0 extruder p term", "", 0x10a, et_fixed, 0, 0, 100,
  "" },
{ "T0_EXTRUDER_I_TERM", "T0 extruder i term", "", 0x10c, et_fixed, 0, 0, 1,
  "" },
{ "T0_EXTRUDER_D_TERM", "T0 extruder d term", "", 0x10e, et_fixed, 0, 0, 100,
  "" },
{ "HBP_P_TERM", "Heatbed p term", "", 0x110, et_fixed, 0, 0, 100,
  "" },
{ "HBP_I_TERM", "T0 extruder i term", "", 0x112, et_fixed, 0, 0, 1,
  "" },
{ "HBP_D_TERM", "T0 extruder d term", "", 0x114, et_fixed, 0, 0, 100,
  "" },
{ "PREHEAT_PREHEAT_RIGHT_TEMP", "Preheat preheat right temp", "C", 0x158, et_ushort, 0, 0, 280,
  "" },
{ "PREHEAT_PREHEAT_PLATFORM_TEMP", "Preheat preheat platform temp", "C", 0x15c, et_ushort, 0, 0, 130,
  "" },
{ "PREHEAT_PREHEAT_LEFT_TEMP", "Preheat preheat left temp", "C", 0x15a, et_ushort, 0, 0, 280,
  "" },
{ "JKN_ADVANCE_K2", "Jkn advance k2", "factor * 100000", 0x1dc, et_ulong, 0, 0, 0,
  "" },
{ "JKN_ADVANCE_K", "Jkn advance k", "factor * 100000", 0x1d8, et_ulong, 0, 0, 0,
  "" },
{ "EXTRUDER_DEPRIME_STEPS_A", "Extruder deprime steps a", "steps", 0x1e0, et_ushort, 0, 0, 0,
  "" },
{ "EXTRUDER_DEPRIME_STEPS_B", "Extruder deprime steps b", "steps", 0x1e2, et_ushort, 0, 0, 0,
  "" },
{ "SLOWDOWN_FLAG", "Slowdown flag", "", 0x1e4, et_boolean, 0, 0, 1,
  "Check or set to 1 to enable automatic print slowdown when the queue of planned segments is running low.  Uncheck or set to 0 to disable automatic slowdown." },
{ "COOLING_FAN_DUTY_CYCLE", "Cooling fan duty cycle", "", 0xf63, et_byte, 0, 0, 100,
  "Set a blower strength (duty cycle) to use for the print cooling fan when it is activated by the print commands.  Select a value between 0% (off) and 100% (on full).  For example, if your fan is too strong, you may want to set this value to 50 so that the fan operates at 50% strength.  If set this value to 0, then the cooling fan will not activate at all when the print commands request it to." },
{ "MACHINE_NAME", "Machine name", "", 0x22, et_string, 16, 0, 0,
  "" },
{ "ALEVEL_MAX_ZDELTA", "Alevel max zdelta", "steps", 0xf66, et_long, 0, 0, 0,
  "The maximum vertical difference between any two probed leveling points may not exceed this value.  Default value is 50 steps (0.5 mm)." },
{ "PSTOP_ENABLE", "Pstop enable", "", 0xf90, et_boolean, 0, 0, 1,
  "Check or set to 1 to enable the optional Pause Stop hardware.  Set to zero or uncheck to disable.  The bot should be power cycled after changing this field." },
{ "DITTO_PRINT_ENABLED", "Ditto print enabled", "", 0xfff, et_boolean, 0, 0, 1,
  "Check or set to 1 to enable ditto printing. Uncheck or set to zero to disable ditto printing." },
{ "SD_USE_CRC", "Sd use crc", "", 0xf91, et_boolean, 0, 0, 1,
  "Check or set to 1 to enable SD card error checkin.  Uncheck or set to 0 to disable." },
{ "CLEAR_FOR_ESTOP", "Clear for estop", "", 0xf8e, et_boolean, 0, 0, 1,
  "Check or set to 1 to instruct the printer to clear the build away from the extruder before stopping.  Uncheck or set to zero to immediately stop the printer (e.g., perform an Emergency Stop)." },
{ "AXIS_HOME_DIRECTION", "Axis home direction", "", 0xc, et_bitfield, 0, 0, 0,
  "A Bitfield representing the XYZAB axes, with X as bit 0. If an axis is homing in the wrong direction, toggle the bit for that axis" },
{ "LED_LED_HEAT", "Led led heat", "", 0x142, et_byte, 0, 1, 0,
  "" },
{ "LED_BASIC_COLOR", "Led basic color", "", 0x140, et_byte, 0, 0, 10,
  "" },
{ "LED_CUSTOM_COLOR_R", "Led custom color r", "RGB", 0x144, et_byte, 0, 0, 0,
  "" },
{ "LED_CUSTOM_COLOR_G", "Led custom color g", "RGB", 0x145, et_byte, 0, 0, 0,
  "" },
{ "LED_CUSTOM_COLOR_B", "Led custom color b", "RGB", 0x146, et_byte, 0, 0, 0,
  "" },
{ "AXIS_HOME_POSITIONS_STEPS_X", "Axis home positions steps x", "steps", 0xe, et_ulong, 0, 0, 0,
  "" },
{ "AXIS_HOME_POSITIONS_STEPS_Y", "Axis home positions steps y", "steps", 0x12, et_ulong, 0, 0, 0,
  "" },
{ "AXIS_HOME_POSITIONS_STEPS_Z", "Axis home positions steps z", "steps", 0x16, et_ulong, 0, 0, 0,
  "" },
{ "AXIS_HOME_POSITIONS_STEPS_A", "Axis home positions steps a", "steps", 0x1a, et_ulong, 0, 0, 0,
  "" },
{ "AXIS_HOME_POSITIONS_STEPS_B", "Axis home positions steps b", "steps", 0x1e, et_ulong, 0, 0, 0,
  "" },
{ "AXIS_STEPS_PER_MM_X", "Axis steps per mm x", "1,000,000 * steps/mm", 0x1a4, et_ulong, 0, 0, 0,
  "" },
{ "AXIS_STEPS_PER_MM_Y", "Axis steps per mm y", "1,000,000 * steps/mm", 0x1a8, et_ulong, 0, 0, 0,
  "" },
{ "AXIS_STEPS_PER_MM_Z", "Axis steps per mm z", "1,000,000 * steps/mm", 0x1ac, et_ulong, 0, 0, 0,
  "" },
{ "AXIS_STEPS_PER_MM_A", "Axis steps per mm a", "1,000,000 * steps/mm", 0x1b0, et_ulong, 0, 0, 0,
  "" },
{ "AXIS_STEPS_PER_MM_B", "Axis steps per mm b", "1,000,000 * steps/mm", 0x1b4, et_ulong, 0, 0, 0,
  "" },
{ "OVERRIDE_GCODE_TEMP", "Override gcode temp", "", 0xffd, et_boolean, 0, 0, 1,
  "Check or set to 1 to override non-zero gcode temperature settings with the pre-heat temperature settings.  Uncheck or set to zero to honor temperature settings in the gcode." },
{ "ENDSTOP_INVERSION", "Endstop inversion", "", 0x4, et_bitfield, 0, 0, 0,
  "" },
{ "TOOL_COUNT", "Tool count", "", 0x42, et_byte, 0, 1, 2,
  "" },
{ "T1_COOLING_SETPOINT_C", "T1 cooling setpoint c", "C", 0x137, et_byte, 0, 0, 300,
  "" },
{ "T1_COOLING_ENABLE", "T1 cooling enable", "", 0x136, et_boolean, 0, 0, 1,
  "" },
{ "T1_EXTRUDER_P_TERM", "T1 extruder p term", "", 0x126, et_fixed, 0, 0, 100,
  "" },
{ "T1_EXTRUDER_I_TERM", "T1 extruder i term", "", 0x128, et_fixed, 0, 0, 1,
  "" },
{ "T1_EXTRUDER_D_TERM", "T1 extruder d term", "", 0x12a, et_fixed, 0, 0, 100,
  "" },
{ "BUZZ_SOUND_ON", "Buzz sound on", "", 0x14a, et_boolean, 0, 0, 1,
  "Check or set to 1 to play bot sounds.  Uncheck or set to 0 for no sounds." },
{ "HEAT_DURING_PAUSE", "Heat during pause", "", 0xffe, et_boolean, 0, 0, 1,
  "Check or set to 1 to leave heaters enabled for up to 30 minutes while the bot is pasued.  Uncheck or set to zero to disable the heaters upon entering a paused state." },
{ "AXIS_INVERSION", "Axis inversion", "", 0x2, et_bitfield, 0, 0, 0,
  "A Bitfield representing the XYZAB axes, with X as bit 0. If an axis is moving in the wrong direction, toggle the bit for that axis" },
{ "DIGI_POT_SETTINGS_0", "Digi pot settings 0", "scale(1-118)", 0x6, et_byte, 0, 0, 0,
  "" },
{ "DIGI_POT_SETTINGS_1", "Digi pot settings 0", "scale(1-118)", 0x7, et_byte, 0, 0, 0,
  "" },
{ "DIGI_POT_SETTINGS_2", "Digi pot settings 0", "scale(1-118)", 0x8, et_byte, 0, 0, 0,
  "" },
{ "DIGI_POT_SETTINGS_3", "Digi pot settings 0", "scale(1-118)", 0x9, et_byte, 0, 0, 0,
  "" },
{ "DIGI_POT_SETTINGS_4", "Digi pot settings 0", "scale(1-118)", 0xa, et_byte, 0, 0, 0,
  "" },
{ "HBP_PRESENT", "Hbp present", "", 0x4c, et_boolean, 0, 0, 1,
  "Check or set to 1 if this machine has a heated build platform; otherwise, uncheck or set to 0 if it does not.  The bot should be power cycled after changing this field." },
{ "TOOLHEAD_OFFSET_SYSTEM", "Toolhead offset system", "", 0xf93, et_boolean, 0, 0, 1,
  "Check to use the NEW dualstrusion system. Uncheck to use the old (RepG 39 and earlier) dualstrusion system.  The bot should be power cycled after changing this field." },
{ "TOOLHEAD_OFFSET_SETTINGS_X", "Toolhead offset settings x", "steps", 0x162, et_long, 0, -2000, 20000,
  "" },
{ "TOOLHEAD_OFFSET_SETTINGS_Y", "Toolhead offset settings y", "steps", 0x166, et_long, 0, -2000, 20000,
  "" },
{ "EXTRUDER_HOLD", "Extruder hold", "", 0xf92, et_boolean, 0, 0, 1,
  "Check or set to 1 to enable the Extruder Hold feature.  Uncheck or set to 0 to disable." },
};
